Assorted spelling and case fixes.

Francois Gouget fgouget at free.fr
Sat Mar 20 09:24:53 CDT 2010


---
 dlls/d3dx9_36/tests/shader.c     |    2 +-
 dlls/inetcomm/tests/mimeintl.c   |    2 +-
 dlls/kernel32/tests/path.c       |    2 +-
 dlls/mmdevapi/tests/propstore.c  |    2 +-
 dlls/mmdevapi/tests/render.c     |    4 ++--
 dlls/msdaps/row_server.c         |    8 ++++----
 dlls/mshtml/view.c               |    2 +-
 dlls/msvfw32/mciwnd.c            |    2 +-
 dlls/oleaut32/tests/dispatch.c   |    2 +-
 dlls/oleaut32/tests/olefont.c    |    5 +++--
 dlls/qedit/samplegrabber.c       |    2 +-
 dlls/quartz/tests/dsoundrender.c |    2 +-
 dlls/shlwapi/ordinal.c           |    2 +-
 dlls/shlwapi/tests/ordinal.c     |    4 ++--
 dlls/shlwapi/url.c               |    2 +-
 dlls/urlmon/urlmon_urlmon.idl    |    2 +-
 dlls/urlmon/usrmarshal.c         |    2 +-
 dlls/user32/tests/combo.c        |    2 +-
 dlls/wined3d/wined3d_private.h   |    2 +-
 dlls/winmm/winmm.c               |    2 +-
 include/amaudio.h                |    2 +-
 include/devpkey.h                |    2 +-
 include/devpropdef.h             |    2 +-
 include/propkey.h                |    2 +-
 24 files changed, 31 insertions(+), 30 deletions(-)

diff --git a/dlls/d3dx9_36/tests/shader.c b/dlls/d3dx9_36/tests/shader.c
index 255e84a..6bf0de3 100644
--- a/dlls/d3dx9_36/tests/shader.c
+++ b/dlls/d3dx9_36/tests/shader.c
@@ -143,7 +143,7 @@ static void test_get_shader_constant_table_ex(void)
         ok(size == 28, "Got result %x, expected 28\n", size);
 
         data = ID3DXConstantTable_GetBufferPointer(constant_table);
-        ok(!memcmp(data, shader_with_ctab + 6, size), "Retreived wrong CTAB data\n");
+        ok(!memcmp(data, shader_with_ctab + 6, size), "Retrieved wrong CTAB data\n");
 
         hr = ID3DXConstantTable_GetDesc(constant_table, NULL);
         ok(hr == D3DERR_INVALIDCALL, "Got result %x, expected %x (D3DERR_INVALIDCALL)\n", hr, D3DERR_INVALIDCALL);
diff --git a/dlls/inetcomm/tests/mimeintl.c b/dlls/inetcomm/tests/mimeintl.c
index 563943f..f64d7d9 100644
--- a/dlls/inetcomm/tests/mimeintl.c
+++ b/dlls/inetcomm/tests/mimeintl.c
@@ -156,7 +156,7 @@ static void test_charset(void)
     hr = MimeOleGetInternat(&internat);
     ok(hr == S_OK, "ret %08x\n", hr);
 
-    hr = IMimeInternational_FindCharset(internat, "non-existent", &hcs);
+    hr = IMimeInternational_FindCharset(internat, "nonexistent", &hcs);
     ok(hr == MIME_E_NOT_FOUND, "got %08x\n", hr);
 
     hr = IMimeInternational_FindCharset(internat, "windows-1252", &hcs_windows_1252);
diff --git a/dlls/kernel32/tests/path.c b/dlls/kernel32/tests/path.c
index be01948..8232fdf 100644
--- a/dlls/kernel32/tests/path.c
+++ b/dlls/kernel32/tests/path.c
@@ -1017,7 +1017,7 @@ static void test_GetLongPathNameA(void)
     /* Test a normal path with a small buffer size */
     memset(temppath, 0, MAX_PATH);
     length = pGetLongPathNameA(tempfile, temppath, 4);
-    /* We have a failure so length should be the minumum plus the terminating '0'  */
+    /* We have a failure so length should be the minimum plus the terminating '0'  */
     ok(length >= lstrlen(tempfile) + 1, "Wrong length\n");
     ok(temppath[0] == 0, "Buffer should not have been touched\n");
 
diff --git a/dlls/mmdevapi/tests/propstore.c b/dlls/mmdevapi/tests/propstore.c
index 3712622..328cdbb 100644
--- a/dlls/mmdevapi/tests/propstore.c
+++ b/dlls/mmdevapi/tests/propstore.c
@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 Maarten Lankhorst for Codeweavers
+ * Copyright 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/dlls/mmdevapi/tests/render.c b/dlls/mmdevapi/tests/render.c
index 05d71b7..cf19129 100644
--- a/dlls/mmdevapi/tests/render.c
+++ b/dlls/mmdevapi/tests/render.c
@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 Maarten Lankhorst for Codeweavers
+ * Copyright 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -177,7 +177,7 @@ static void test_audioclient(IAudioClient *ac)
     ok(hr == E_INVALIDARG, "Initialize with invalid flags returns %08x\n", hr);
 
     /* It seems that if length > 2s or periodicity != 0 the length is ignored and call succeeds
-     * Since we can only initialize succesfully once skip those tests
+     * Since we can only initialize successfully once, skip those tests.
      */
     hr = IAudioClient_Initialize(ac, AUDCLNT_SHAREMODE_SHARED, 0, 5000000, 0, NULL, NULL);
     ok(hr == E_POINTER, "Initialize with null format returns %08x\n", hr);
diff --git a/dlls/msdaps/row_server.c b/dlls/msdaps/row_server.c
index f443155..4fc41c4 100644
--- a/dlls/msdaps/row_server.c
+++ b/dlls/msdaps/row_server.c
@@ -838,7 +838,7 @@ static HRESULT create_row_proxy(IWineRowServer *server, IUnknown **obj)
     proxy->server = server;
 
     *obj = (IUnknown*)&proxy->row_vtbl;
-    TRACE("returing %p\n", *obj);
+    TRACE("returning %p\n", *obj);
     return S_OK;
 }
 
@@ -1339,7 +1339,7 @@ HRESULT create_rowset_proxy(IWineRowServer *server, IUnknown **obj)
     proxy->server = server;
 
     *obj = (IUnknown *)&proxy->rowset_vtbl;
-    TRACE("returing %p\n", *obj);
+    TRACE("returning %p\n", *obj);
     return S_OK;
 }
 
@@ -1474,7 +1474,7 @@ static HRESULT WINAPI marshal_UnmarshalInterface(IMarshal *iface, IStream *strea
         IWineRowServer_Release(server);
     }
 
-    TRACE("returing %p\n", *obj);
+    TRACE("returning %p\n", *obj);
     return hr;
 }
 
@@ -1522,7 +1522,7 @@ static HRESULT create_marshal(IUnknown *outer, const CLSID *class, void **obj)
     marshal->ref = 1;
 
     *obj = &marshal->marshal_vtbl;
-    TRACE("returing %p\n", *obj);
+    TRACE("returning %p\n", *obj);
     return S_OK;
 }
 
diff --git a/dlls/mshtml/view.c b/dlls/mshtml/view.c
index 261e959..2561478 100644
--- a/dlls/mshtml/view.c
+++ b/dlls/mshtml/view.c
@@ -811,7 +811,7 @@ static HRESULT WINAPI ViewObject_SetAdvise(IViewObjectEx *iface, DWORD aspects,
     TRACE("(%p)->(%d %d %p)\n", This, aspects, advf, pAdvSink);
 
     if(aspects != DVASPECT_CONTENT || advf != ADVF_PRIMEFIRST)
-        FIXME("unsuported arguments\n");
+        FIXME("unsupported arguments\n");
 
     if(This->doc_obj->view_sink)
         IAdviseSink_Release(This->doc_obj->view_sink);
diff --git a/dlls/msvfw32/mciwnd.c b/dlls/msvfw32/mciwnd.c
index 64a19ca..96b6420 100644
--- a/dlls/msvfw32/mciwnd.c
+++ b/dlls/msvfw32/mciwnd.c
@@ -1300,7 +1300,7 @@ end_of_mci_open:
     case MCI_SEEK:
     case MCI_STEP:
         {
-            MCI_SEEK_PARMS mci_seek; /* Layout is useable as MCI_XYZ_STEP_PARMS */
+            MCI_SEEK_PARMS mci_seek; /* Layout is usable as MCI_XYZ_STEP_PARMS */
             DWORD flags = MCI_STEP == wMsg ? 0 :
                           MCIWND_START == lParam ? MCI_SEEK_TO_START :
                           MCIWND_END   == lParam ? MCI_SEEK_TO_END : MCI_TO;
diff --git a/dlls/oleaut32/tests/dispatch.c b/dlls/oleaut32/tests/dispatch.c
index a0e418b..0f52241 100644
--- a/dlls/oleaut32/tests/dispatch.c
+++ b/dlls/oleaut32/tests/dispatch.c
@@ -255,7 +255,7 @@ static void test_DispGetParam(void)
 
     CLEAR_VARARG(vararg);
 
-    /* Coerce the the first parameter, which is of type VT_EMPTY, to VT_BSTR. */
+    /* Coerce the first parameter, which is of type VT_EMPTY, to VT_BSTR. */
     VariantInit(&vararg[0]);
     INIT_DISPPARAMS(dispparams, vararg, NULL, 1, 0);
     VariantInit(&result);
diff --git a/dlls/oleaut32/tests/olefont.c b/dlls/oleaut32/tests/olefont.c
index 2f3eff8..7c0a112 100644
--- a/dlls/oleaut32/tests/olefont.c
+++ b/dlls/oleaut32/tests/olefont.c
@@ -954,8 +954,9 @@ static void test_hfont_lifetime(void)
         ok(obj_type == 0, "%d: got obj type %d\n", i, obj_type);
     }
 
-    /* Interestingly if we release a non-existent reference on the hfont, it persists
-       until the font object is released */
+    /* Interestingly if we release a nonexistent reference on the hfont,
+     * it persists until the font object is released
+     */
     for(i = 0; i < 100; i++)
     {
         size.int64 = (i + 10) * 20000;
diff --git a/dlls/qedit/samplegrabber.c b/dlls/qedit/samplegrabber.c
index 1875c51..c615353 100644
--- a/dlls/qedit/samplegrabber.c
+++ b/dlls/qedit/samplegrabber.c
@@ -854,7 +854,7 @@ SampleGrabber_ISampleGrabber_GetCurrentBuffer(ISampleGrabber *iface, LONG *bufSi
 static HRESULT WINAPI
 SampleGrabber_ISampleGrabber_GetCurrentSample(ISampleGrabber *iface, IMediaSample **sample)
 {
-    /* MS doesn't implement it either, noone should call it */
+    /* MS doesn't implement it either, no one should call it */
     WARN("(%p): not implemented\n", sample);
     return E_NOTIMPL;
 }
diff --git a/dlls/quartz/tests/dsoundrender.c b/dlls/quartz/tests/dsoundrender.c
index e5dcac7..5ecdaaa 100644
--- a/dlls/quartz/tests/dsoundrender.c
+++ b/dlls/quartz/tests/dsoundrender.c
@@ -1,7 +1,7 @@
 /*
  * Unit tests for DSound Renderer functions
  *
- * Copyright (C) 2010 Maarten Lankhorst for Codeweavers
+ * Copyright (C) 2010 Maarten Lankhorst for CodeWeavers
  * Copyright (C) 2007 Google (Lei Zhang)
  *
  * This library is free software; you can redistribute it and/or
diff --git a/dlls/shlwapi/ordinal.c b/dlls/shlwapi/ordinal.c
index 364bbfe..c2aa216 100644
--- a/dlls/shlwapi/ordinal.c
+++ b/dlls/shlwapi/ordinal.c
@@ -500,7 +500,7 @@ HRESULT WINAPI GetAcceptLanguagesW( LPWSTR langbuf, LPDWORD buflen)
         return S_OK;
     }
 
-    /* Did not find a value in the registry or the user buffer is to small */
+    /* Did not find a value in the registry or the user buffer is too small */
     mylcid = GetUserDefaultLCID();
     retval = LcidToRfc1766W(mylcid, mystr, mystrlen);
     len = lstrlenW(mystr);
diff --git a/dlls/shlwapi/url.c b/dlls/shlwapi/url.c
index 958a842..4d064b6 100644
--- a/dlls/shlwapi/url.c
+++ b/dlls/shlwapi/url.c
@@ -662,7 +662,7 @@ HRESULT WINAPI UrlCombineW(LPCWSTR pszBase, LPCWSTR pszRelative,
             }
         }
 
-        /* If there is a '#' and the characters immediately preceeding it are
+        /* If there is a '#' and the characters immediately preceding it are
          * ".htm[l]", then begin looking for the last leaf starting from
          * the '#'. Otherwise the '#' is not meaningful and just start
          * looking from the end. */
diff --git a/dlls/urlmon/urlmon_urlmon.idl b/dlls/urlmon/urlmon_urlmon.idl
index 71a0719..d45ba07 100644
--- a/dlls/urlmon/urlmon_urlmon.idl
+++ b/dlls/urlmon/urlmon_urlmon.idl
@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Piotr Caban for Codeweavers
+ * Copyright 2009 Piotr Caban for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/dlls/urlmon/usrmarshal.c b/dlls/urlmon/usrmarshal.c
index b945563..6ff8f04 100644
--- a/dlls/urlmon/usrmarshal.c
+++ b/dlls/urlmon/usrmarshal.c
@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Piotr Caban for Codeweavers
+ * Copyright 2009 Piotr Caban for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/dlls/user32/tests/combo.c b/dlls/user32/tests/combo.c
index bee685c..faf2145 100644
--- a/dlls/user32/tests/combo.c
+++ b/dlls/user32/tests/combo.c
@@ -461,7 +461,7 @@ static void test_editselection(void)
     ok(LOWORD(len)==1, "Unexpected start position for selection %d\n", LOWORD(len));
     ok(HIWORD(len)==1, "Unexpected end position for selection %d\n", HIWORD(len));
 
-    /* Now what happens when it gets more focus a second time - it doesnt reselect */
+    /* Now what happens when it gets more focus a second time - it doesn't reselect */
     SendMessage(hCombo, WM_SETFOCUS, 0, (LPARAM)hEdit);
     len = SendMessage(hCombo, CB_GETEDITSEL, 0,0);
     ok(LOWORD(len)==1, "Unexpected start position for selection %d\n", LOWORD(len));
diff --git a/dlls/wined3d/wined3d_private.h b/dlls/wined3d/wined3d_private.h
index 9cd58ca..db063dc 100644
--- a/dlls/wined3d/wined3d_private.h
+++ b/dlls/wined3d/wined3d_private.h
@@ -2474,7 +2474,7 @@ struct wined3d_map_range
 #define WINED3D_BUFFER_CREATEBO     0x04    /* Attempt to create a buffer object next PreLoad */
 #define WINED3D_BUFFER_DOUBLEBUFFER 0x08    /* Use a vbo and local allocated memory */
 #define WINED3D_BUFFER_FLUSH        0x10    /* Manual unmap flushing */
-#define WINED3D_BUFFER_DISCARD      0x20    /* A DISCARD lock has occured since the last PreLoad */
+#define WINED3D_BUFFER_DISCARD      0x20    /* A DISCARD lock has occurred since the last PreLoad */
 #define WINED3D_BUFFER_NOSYNC       0x40    /* All locks since the last PreLoad had NOOVERWRITE set */
 
 struct wined3d_buffer
diff --git a/dlls/winmm/winmm.c b/dlls/winmm/winmm.c
index 99e0361..6cdf14d 100644
--- a/dlls/winmm/winmm.c
+++ b/dlls/winmm/winmm.c
@@ -1822,7 +1822,7 @@ MMRESULT WINAPI midiStreamOut(HMIDISTRM hMidiStrm, LPMIDIHDR lpMidiHdr,
     if (cbMidiHdr < offsetof(MIDIHDR,dwOffset) || !lpMidiHdr || !lpMidiHdr->lpData
 	|| lpMidiHdr->dwBufferLength < lpMidiHdr->dwBytesRecorded)
 	return MMSYSERR_INVALPARAM;
-    /* FIXME: Native additionaly checks if the MIDIEVENTs in lpData
+    /* FIXME: Native additionally checks if the MIDIEVENTs in lpData
      * exactly fit dwBytesRecorded. */
 
     if (!(lpMidiHdr->dwFlags & MHDR_PREPARED))
diff --git a/include/amaudio.h b/include/amaudio.h
index ed3a832..8003eef 100644
--- a/include/amaudio.h
+++ b/include/amaudio.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Maarten Lankhorst for Codeweavers
+ * Copyright (C) 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/include/devpkey.h b/include/devpkey.h
index 04d68de..46c8c39 100644
--- a/include/devpkey.h
+++ b/include/devpkey.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Maarten Lankhorst for Codeweavers
+ * Copyright (C) 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/include/devpropdef.h b/include/devpropdef.h
index 5eed9e7..8db292c 100644
--- a/include/devpropdef.h
+++ b/include/devpropdef.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Maarten Lankhorst for Codeweavers
+ * Copyright (C) 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/include/propkey.h b/include/propkey.h
index 2a940d4..1d09d6f 100644
--- a/include/propkey.h
+++ b/include/propkey.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Maarten Lankhorst for Codeweavers
+ * Copyright (C) 2010 Maarten Lankhorst for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
diff --git a/dlls/shlwapi/tests/ordinal.c b/dlls/shlwapi/tests/ordinal.c
index 17813c1..fe6b827 100644
--- a/dlls/shlwapi/tests/ordinal.c
+++ b/dlls/shlwapi/tests/ordinal.c
@@ -186,7 +186,7 @@ static void test_GetAcceptLanguagesA(void)
         /* There is no space for the string in the registry.
            When the buffer is large enough, the default language is returned
 
-           When the buffer is to small for that fallback, win7_32 and w2k8_64
+           When the buffer is too small for that fallback, win7_32 and w2k8_64
            and above fail with HRESULT_FROM_WIN32(ERROR_INSUFFICIENT_BUFFER), but
            recent os succeed and return a partial result while
            older os succeed and overflow the buffer */
@@ -254,7 +254,7 @@ static void test_GetAcceptLanguagesA(void)
     memset(buffer, '#', maxlen);
     buffer[maxlen] = 0;
     hr = pGetAcceptLanguagesA( buffer, &len);
     /* When the buffer is to small, win7_32 and w2k8_64 and above fail with
        HRESULT_FROM_WIN32(ERROR_INSUFFICIENT_BUFFER), other versions suceed
        and return a partial 0 terminated result while other versions
        fail with E_INVALIDARG and return a partial unterminated result */
@@ -254,7 +254,7 @@ static void test_GetAcceptLanguagesA(void)
     buffer[maxlen] = 0;
     hr = pGetAcceptLanguagesA( buffer, &len);
-    /* When the buffer is to small, win7_32 and w2k8_64 and above fail with
+    /* When the buffer is too small, win7_32 and w2k8_64 and above fail with
        HRESULT_FROM_WIN32(ERROR_INSUFFICIENT_BUFFER), other versions suceed
        and return a partial 0 terminated result while other versions
-- 
1.6.5




More information about the wine-patches mailing list